==> riseup-vpn-0.21.11.tar.gz: bitmask-vpn-0.21.11/gui/i18n/base.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>About</name>
    <message>
        <location filename="../components/About.qml" line="9"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="80"/>
        <source>&lt;p&gt;This service is paid for entirely by donations from users like you. &lt;a href=&quot;%1&quot;&gt;Please donate&lt;/a&gt;.&lt;/p&gt;</source>
        <extracomment>donation text of the about dialog</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="102"/>
        <source>%1 version: 
%2</source>
        <extracomment>%1 -&gt; application name %2 -&gt; version string</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../components/Footer.qml" line="171"/>
        <source>Recommended</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../components/Help.qml" line="7"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="20"/>
        <source>Troubleshooting and support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="31"/>
        <source>Report a bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="42"/>
        <source>How to uninstall</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InitErrors</name>
    <message>
        <location filename="../components/InitErrors.qml" line="31"/>
        <source>Could not find helpers. Please check your installation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/InitErrors.qml" line="44"/>
        <source>Could not find polkit agent.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Locations</name>
    <message>
        <location filename="../components/Locations.qml" line="21"/>
        <source>Select Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="27"/>
        <source>Automatically use best connection</source>
        <extracomment>this is in the radio button for the auto selection</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="29"/>
        <source>Manually select</source>
        <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="31"/>
        <source>Switching gateway…</source>
        <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="33"/>
        <source>Only locations with bridges</source>
        <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="65"/>
        <source>Recommended</source>
        <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../components/MainView.qml" line="33"/>
        <location filename="../components/MainView.qml" line="53"/>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="46"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="60"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="68"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="76"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="107"/>
        <source>Please donate!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="121"/>
        <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../components/Preferences.qml" line="10"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="38"/>
        <source>Turn off the VPN to make changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="48"/>
        <source>Censorship circumvention</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="56"/>
        <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="70"/>
        <source>Use obfs4 bridges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="96"/>
        <source>Traffic is obfuscated to bypass blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="109"/>
        <source>Use Snowflake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="124"/>
        <source>Snowflake needs Tor installed in your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="136"/>
        <source>Transport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="144"/>
        <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="157"/>
        <source>Use UDP if available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Splash</name>
    <message>
        <location filename="../components/Splash.qml" line="100"/>
        <source>There is a newer version available. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="100"/>
        <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="104"/>
        <source>UPGRADE NOW</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Systray</name>
    <message>
        <location filename="../components/Systray.qml" line="16"/>
        <source>Checking status…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="36"/>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Hide</source>
        <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="57"/>
        <source>Quit</source>
        <extracomment>Part of the systray menu; quits que application</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="72"/>
        <source>Connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="74"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="77"/>
        <source>Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VPNState</name>
    <message>
        <location filename="../components/VPNState.qml" line="26"/>
        <location filename="../components/VPNState.qml" line="125"/>
        <source>Connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="58"/>
        <source>Unsecured
Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="71"/>
        <source>Turn on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="91"/>
        <source>Secured
Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="104"/>
        <source>Turn off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="139"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="223"/>
        <source>%1 off</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="223"/>
        <source>off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="226"/>
        <source>%1 on</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="229"/>
        <source>Connecting to %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="232"/>
        <source>Stopping %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="235"/>
        <source>%1 blocking internet</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VPNSwitch</name>
    <message>
        <location filename="../qml/VPNSwitch.qml" line="10"/>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>: a fast and secure VPN. Powered by Bitmask.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <source>Enable Web API.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Install helpers (Linux only, requires sudo).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>Disable autostart for the next run.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>Web API port (default: 8080)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="119"/>
        <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> riseup-vpn-0.24.3.tar.gz: bitmask-vpn-0.24.3/gui/i18n/base.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>About</name>
    <message>
        <location filename="../components/About.qml" line="9"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="80"/>
        <source>&lt;p&gt;This service is paid for entirely by donations from users like you. &lt;a href=&quot;%1&quot;&gt;Please donate&lt;/a&gt;.&lt;/p&gt;</source>
        <extracomment>donation text of the about dialog</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="103"/>
        <source>%1 version: 
%2</source>
        <extracomment>screenshot https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/screenshots/about.png %1 -&gt; application name %2 -&gt; version string</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../components/Footer.qml" line="171"/>
        <source>Recommended</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../components/Help.qml" line="7"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="20"/>
        <source>Troubleshooting and support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="31"/>
        <source>Report a bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="42"/>
        <source>How to uninstall</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InitErrors</name>
    <message>
        <location filename="../components/InitErrors.qml" line="31"/>
        <source>Could not find helpers. Please check your installation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/InitErrors.qml" line="44"/>
        <source>Could not find polkit agent.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Locations</name>
    <message>
        <location filename="../components/Locations.qml" line="21"/>
        <source>Select Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="27"/>
        <source>Automatically use best connection</source>
        <extracomment>this is in the radio button for the auto selection</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="29"/>
        <source>Manually select</source>
        <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="31"/>
        <source>Switching gateway…</source>
        <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="33"/>
        <source>Only locations with bridges</source>
        <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="65"/>
        <source>Recommended</source>
        <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../components/MainView.qml" line="32"/>
        <location filename="../components/MainView.qml" line="56"/>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="49"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="63"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="70"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="77"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="104"/>
        <source>Please donate!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="118"/>
        <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../components/Preferences.qml" line="11"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="54"/>
        <source>Turn off the VPN to make changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="69"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="102"/>
        <source>Censorship circumvention</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="110"/>
        <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="124"/>
        <source>Use obfs4 bridges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="150"/>
        <source>Traffic is obfuscated to bypass blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="164"/>
        <source>Use Snowflake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="179"/>
        <source>Snowflake needs Tor installed in your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="192"/>
        <source>Transport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="200"/>
        <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="213"/>
        <source>Use UDP if available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Splash</name>
    <message>
        <location filename="../components/Splash.qml" line="100"/>
        <source>There is a newer version available. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="100"/>
        <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="104"/>
        <source>UPGRADE NOW</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusBox</name>
    <message>
        <location filename="../components/StatusBox.qml" line="91"/>
        <source>This can take several minutes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Systray</name>
    <message>
        <location filename="../components/Systray.qml" line="16"/>
        <source>Checking status…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="36"/>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Hide</source>
        <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="57"/>
        <source>Quit</source>
        <extracomment>Part of the systray menu; quits the application</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="74"/>
        <source>Connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="76"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="79"/>
        <source>Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VPNState</name>
    <message>
        <location filename="../components/VPNState.qml" line="27"/>
        <source>Setting up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="52"/>
        <location filename="../components/VPNState.qml" line="156"/>
        <source>Connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="85"/>
        <source>Unsecured
Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="100"/>
        <source>Turn on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="120"/>
        <source>Secured
Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="135"/>
        <source>Turn off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="172"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="256"/>
        <source>%1 off</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="256"/>
        <source>off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="259"/>
        <source>%1 on</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="262"/>
        <source>Connecting to %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>Stopping %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="268"/>
        <source>%1 blocking internet</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="276"/>
        <source>pluggable transport connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="278"/>
        <source>connection done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="280"/>
        <source>doing handshake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="282"/>
        <source>handshake done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="284"/>
        <source>creating one-hop connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="286"/>
        <source>requesting status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="288"/>
        <source>loading status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="290"/>
        <source>loading keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="292"/>
        <source>requesting descriptors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="294"/>
        <source>loading descriptors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="296"/>
        <source>creating circuit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="298"/>
        <source>done</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VPNSwitch</name>
    <message>
        <location filename="../qml/VPNSwitch.qml" line="10"/>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="144"/>
        <source>: a fast and secure VPN. Powered by Bitmask.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="151"/>
        <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="158"/>
        <source>Enable Web API.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="164"/>
        <source>Install helpers (Linux only, requires sudo).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="170"/>
        <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="176"/>
        <source>Enable autostart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="181"/>
        <source>Web API port (default: 8080)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="184"/>
        <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
